assumptions: Retrieve the assumptions the likelihood model makes about the...

View source: R/core-generics.R

assumptionsR Documentation

Retrieve the assumptions the likelihood model makes about the data.

Description

Retrieve the assumptions the likelihood model makes about the data.

Usage

assumptions(model, ...)

Arguments

model

The likelihood model

...

Additional arguments

Value

A list of assumptions


likelihood.model documentation built on March 19, 2026, 9:07 a.m.