| fisherian | R Documentation |
Functions for pure likelihood-based inference in the Fisherian tradition. These emphasize the likelihood function itself as the primary object of inference, without requiring probability statements about parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.