hess_loglik.likelihood_model: Default method to compute the hessian of the log-likelihood.

View source: R/core-generics.R

hess_loglik.likelihood_modelR Documentation

Default method to compute the hessian of the log-likelihood.

Description

In case a hess_loglik method is not provided, this function will be used. It computes the hessian of the log-likelihood function using numerical differentiation.

Usage

## S3 method for class 'likelihood_model'
hess_loglik(model, control = list(), ...)

Arguments

model

The likelihood model

control

Custom arguments to pass to numDeriv::hessian.

...

Additional arguments (to pass into loglik)

Value

A function(df, par, ...) that computes the Hessian matrix of the log-likelihood evaluated at par given data df.


likelihood.model documentation built on March 19, 2026, 9:07 a.m.