View source: R/core-fisherian.R
| profile_loglik | R Documentation |
Computes the profile log-likelihood for a subset of parameters. For each value of the parameters of interest, the remaining (nuisance) parameters are optimized out.
profile_loglik(x, ...)
## S3 method for class 'fisher_mle'
profile_loglik(
x,
data,
model,
param,
grid = NULL,
n_grid = 50,
range_mult = 4,
...
)
x |
A fisher_mle object |
... |
Additional arguments passed to loglik |
data |
Data frame used for likelihood computation |
model |
The likelihood model used for fitting |
param |
Index or name of parameter(s) to profile |
grid |
Optional grid of values to evaluate (vector or matrix) |
n_grid |
Number of grid points if grid not specified (default 50) |
range_mult |
Multiplier for grid range based on SE (default 4) |
The profile likelihood is useful for:
Visualizing the likelihood surface
Computing likelihood intervals
Eliminating nuisance parameters
A data frame with parameter values and profile log-likelihood
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.