View source: R/core-generics.R
| rdata | R Documentation |
Returns a function that generates random data from the model's data-generating process (DGP) at a given parameter value.
rdata(model, ...)
model |
A likelihood model |
... |
Additional arguments |
This is used by the default fim method for Monte Carlo estimation
of the Fisher information matrix.
Function that takes (theta, n, ...) and returns a data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.