View source: R/core-generics.R
| rdata.likelihood_model | R Documentation |
Provides a clear error when a model class does not implement rdata.
The rdata method is required by the default fim.likelihood_model()
for Monte Carlo FIM estimation.
## S3 method for class 'likelihood_model'
rdata(model, ...)
model |
A likelihood model |
... |
Additional arguments |
Never returns; always errors.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.