sampler.fisher_boot: Bootstrap sampler for fisher_boot

View source: R/core-fisher_mle.R

sampler.fisher_bootR Documentation

Bootstrap sampler for fisher_boot

Description

Returns a function that resamples from the bootstrap distribution.

Usage

## S3 method for class 'fisher_boot'
sampler(x, ...)

Arguments

x

A fisher_boot object

...

Additional arguments (ignored)

Value

Function that takes n and returns n x p matrix of resampled estimates


likelihood.model documentation built on March 19, 2026, 9:07 a.m.