sampler.fisher_mle: Asymptotic sampler for fisher_mle

View source: R/core-fisher_mle.R

sampler.fisher_mleR Documentation

Asymptotic sampler for fisher_mle

Description

Returns a function that samples from the asymptotic normal distribution of the MLE: N(theta_hat, vcov).

Usage

## S3 method for class 'fisher_mle'
sampler(x, ...)

Arguments

x

A fisher_mle object

...

Additional arguments (ignored)

Value

Function that takes n and returns n x p matrix of samples


likelihood.model documentation built on March 19, 2026, 9:07 a.m.