| sampler.likelihood_model | R Documentation |
We use the bootstrap method. In other words, we treat the data as an empirical distribution and sample from it to get a new dataset, then we fit the model to that dataset and return the MLE. We do this R times and return the R MLEs.
## S3 method for class 'likelihood_model'
sampler(x, df, par, ..., nthreads = 1L)
x |
The likelihood model |
df |
Data frame to bootstrap from |
par |
Initial parameter values |
... |
Additional arguments to pass into the likelihood model |
nthreads |
The number of threads to use for parallelization |
This is the default method, but if you want to use a different method, you should define your own method for your likelihood model.
A function that returns a bootstrapped sampling distribution of an MLE (fisher_boot object).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.