score: Score method

View source: R/core-generics.R

scoreR Documentation

Score method

Description

This function returns the score function of a model

Usage

score(model, ...)

Arguments

model

The likelihood model

...

Additional arguments

Value

A function to compute the score given a data frame and parameters


likelihood.model documentation built on March 19, 2026, 9:07 a.m.