score.likelihood_model: Default score method

View source: R/core-generics.R

score.likelihood_modelR Documentation

Default score method

Description

In case a score method is not provided, this function will be used. It computes the score by numerical differentiation of the log-likelihood.

Usage

## S3 method for class 'likelihood_model'
score(model, control = list(), ...)

Arguments

model

The likelihood model

control

Custom arguments to pass to numDeriv::grad.

...

Additional arguments (to pass into loglik)

Value

A function to compute the score given a data frame and parameters


likelihood.model documentation built on March 19, 2026, 9:07 a.m.