View source: R/core-fisher_mle.R
| sampler.fisher_boot | R Documentation |
Returns a function that resamples from the bootstrap distribution.
## S3 method for class 'fisher_boot'
sampler(x, ...)
x |
A fisher_boot object |
... |
Additional arguments (ignored) |
Function that takes n and returns n x p matrix of resampled estimates
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.