View source: R/core-fisher_mle.R
| sampler.fisher_mle | R Documentation |
Returns a function that samples from the asymptotic normal distribution of the MLE: N(theta_hat, vcov).
## S3 method for class 'fisher_mle'
sampler(x, ...)
x |
A fisher_mle object |
... |
Additional arguments (ignored) |
Function that takes n and returns n x p matrix of samples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.