View source: R/core-generics.R
| score | R Documentation |
This function returns the score function of a model
score(model, ...)
model |
The likelihood model |
... |
Additional arguments |
A function to compute the score given a data frame and parameters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.