View source: R/core-generics.R
| score.likelihood_model | R Documentation |
In case a score method is not provided, this function will be used.
It computes the score by numerical differentiation of the log-likelihood.
## S3 method for class 'likelihood_model'
score(model, control = list(), ...)
model |
The likelihood model |
control |
Custom arguments to pass to |
... |
Additional arguments (to pass into |
A function to compute the score given a data frame and parameters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.